<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+88"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+76"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+107"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="+103"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+79"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Centro, Ponto, Ângulos
Arco com Centro, Ponto, Ângulos</translatorcomment>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="-2"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+115"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="+105"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="+104"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="+105"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+91"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+89"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+92"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+76"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+82"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+70"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+106"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+77"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+88"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+74"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+77"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>X</source>
        <translatorcomment>--exact match--
--file: pt.po--
Encerrando o aplicativo...
Exportando o desenho...</translatorcomment>
        <translation>X</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Y</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Modifique
Modifique
&amp;Camada</translatorcomment>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Z</source>
        <translatorcomment>--google--
Oculte (congele) todos os carimbos
Mostre (descongele) todos os carimbos
&amp;Horizontal</translatorcomment>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Radius</source>
        <translatorcomment>--exact match--
--file: pt.po--
Indique o raio
Arco tangencial à entidade de base com raio</translatorcomment>
        <translation>Raio</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-9"/>
        <source>Start Angle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Indique o ângulo de início:
Indique o ângulo de início</translatorcomment>
        <translation>Ângulo de Início</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>End Angle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Indique o ângulo de fim ou [Ângulo/Comprimento da corda]
Indique o ângulo de término</translatorcomment>
        <translation>Ângulo Final</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>Reversed</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Invertido</translatorcomment>
        <translation>Invertido</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <source>Diameter</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Comute o símbolo de diâmetro
Diâmetro (ø)</translatorcomment>
        <translation>Diâmetro</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+9"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+2"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+3"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+2"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+2"/>
        <source>Length</source>
        <translatorcomment>--exact match--
--file: pt.po--
Não é um comprimento de corda válido
Indique o ângulo de fim ou [Ângulo/Comprimento da corda]</translatorcomment>
        <translation>Comprimento</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <source>Total Length</source>
        <translation>Comprimento total</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sweep Angle</source>
        <translation>Ângulo de Varredura</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <source>Area</source>
        <translatorcomment>--exact match--
--file: pt.po--
Á&amp;rea de Poligonal
Meça a área e a circunferência de um polígono</translatorcomment>
        <translation>Área</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <source>Total Area</source>
        <translation>Área total</translation>
    </message>
    <message>
        <location filename="../src/entity/RCircleEntity.cpp" line="-1"/>
        <source>Circumference</source>
        <translatorcomment>--google--
Meça a área e a circunferência de um polígono
Área/circunferência
Circunferência: %1</translatorcomment>
        <translation>Circunferência</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Line</source>
        <translatorcomment>--google--
Indique a dimensão da linha de localização
Insira o ângulo da linha de dimensão:
Insira o ângulo da linha de dimensão</translatorcomment>
        <translation>Linha de Dimensão</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 1</source>
        <translatorcomment>--google--
Ponto de Extensão 1|X
Ponto de Extensão 1|Y</translatorcomment>
        <translation>Ponto de Extensão 1</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 2</source>
        <translatorcomment>--google--
Ponto de Extensão 2|X
Ponto de Extensão 2|Y</translatorcomment>
        <translation>Ponto de Extensão 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Início da Linha 1</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 End</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Final da Linha 1</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 Start</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Início da Linha 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 End</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Final da Linha 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Arc</source>
        <translation>Arco de Dimensionamento</translation>
    </message>
    <message>
        <source>Dimenion Arc</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Arc Dimenion</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-6"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Chord Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ponto de Corda</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Far Chord Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ponto de Corda Distante</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-5"/>
        <location line="+1"/>
        <source>Origin</source>
        <translatorcomment>--google--
Indique a primeira extensão da linha de origem
Indique a segunda extensão da linha de origem
&amp;Apague o Original</translatorcomment>
        <translation>Origem</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Ordene
Ordene
Ordene dimensão</translatorcomment>
        <translation>Ordenada</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Defining Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Definindo o Ponto</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Leader End Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ponto Final Condutor</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimRotatedEntity.cpp" line="+121"/>
        <source>Dimension Angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ângulo de Dimensão</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-8"/>
        <source>Label</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Rótulo:
Entre o rótulo fixo ou deixe-o vazio para rotulação automática</translatorcomment>
        <translation>Rótulo</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Tolerance</source>
        <translatorcomment>--exact match--
--file: pt.po--
Tolerância superior
Tolerância Inferior</translatorcomment>
        <translation>Tolerância</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Upper Limit</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Limite Superior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lower Limit</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Limite Inferior</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Definition Point</source>
        <translation>Ponto de Definição</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Flip First Arrow</source>
        <translation>Virar a primeira seta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Flip Second Arrow</source>
        <translation>Virar a segunda seta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Fixed Extension Line</source>
        <translation>Linha de extensão fixa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension Line Length</source>
        <translation>Comprimento linha de extensão</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Auto Label</source>
        <translation>Rótulo Automático</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linear Factor</source>
        <translation>Fator Linear</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block Name</source>
        <translation>Nome do bloco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Auto Label Position</source>
        <translation>Posição do Rótulo Automático</translation>
    </message>
    <message>
        <source>Definitionpoint</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Definitionpoint</translation>
    </message>
    <message>
        <location line="-21"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Posição do Texto</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Measured Value</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Valor Medido</translation>
    </message>
    <message>
        <location filename="../src/entity/REllipseEntity.cpp" line="-17"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Major Point</source>
        <translatorcomment>--google--
Ponto Maior|X
Ponto Maior|Y</translatorcomment>
        <translation>Ponto Maior</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ratio</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Razão
Operação interrompida pelo utilizador</translatorcomment>
        <translation>Razão</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start Parameter</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Parâmetro Inicial</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Parameter</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Parâmetro Final</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-9"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Point</source>
        <translatorcomment>--google--
Ponto inicial (x):
Ponto inicial (x)
Ponto inicial (y):</translatorcomment>
        <translation>Ponto Inicial</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Point</source>
        <translatorcomment>--google--
Ponto final (y):
Ponto final (y)
Ponto final (x):</translatorcomment>
        <translation>Ponto Final</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="-8"/>
        <source>Solid</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Desenhe hachurados e preenchimentos sólidos
Hachuras / preenchimentos sólidos</translatorcomment>
        <translation>Sólido</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Pattern</source>
        <translatorcomment>--exact match--
--file: pt.po--
Padrão
Padrões de Hachura:</translatorcomment>
        <translation>Textura</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Name</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
documento sem nome %1
Salvando o desenho com novo nome...
R&amp;enomeie Carimbo</translatorcomment>
        <translation>Nome</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>From Entity</source>
        <translation>De entidade</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+14"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+2"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <source>Angle</source>
        <translatorcomment>--exact match--
--file: pt.po--
Entre o ângulo:
Insira o ângulo da linha de dimensão:</translatorcomment>
        <translation>Ângulo</translation>
    </message>
    <message>
        <location line="+192"/>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+2"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-191"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+2"/>
        <source>Scale</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Escalone
Escalone entidades</translatorcomment>
        <translation>Escala</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+2"/>
        <location line="+1"/>
        <source>Vertex</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Vértice</translation>
    </message>
    <message>
        <location filename="../src/entity/RImageEntity.cpp" line="-18"/>
        <source>File</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
&amp;Arquivo
Criando o novo arquivo...</translatorcomment>
        <translation>Arquivo</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPointEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Indique a dimensão da linha de posicionamento ou insira o ângulo:
Indique a posição [ângulo/comprimento]</translatorcomment>
        <translation>Posição</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width Factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Fator de Largura</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height Factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Fator de Altura</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Largura:
Espessura:
&amp;Largura do Papel:</translatorcomment>
        <translation>Largura</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Altura:
&amp;Altura do Papel:</translatorcomment>
        <translation>Altura</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Fade</source>
        <translation>Esmaecimento</translation>
    </message>
    <message>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-4"/>
        <source>Arrow</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pt.ts--
Conduza (seqüência linear com seta)
Tamanho da seta:</translatorcomment>
        <translation>Seta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow Block</source>
        <translation>Seta bloco</translation>
    </message>
    <message>
        <source>Clockwise</source>
        <translation type="vanished">Horário</translation>
    </message>
    <message>
        <source>Counterclockwise</source>
        <translation type="vanished">Anti-horário</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-9"/>
        <source>Polyline Pattern</source>
        <translation>Padrão para Polilinha</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Closed</source>
        <translatorcomment>--exact match--
--file: pt.po--
Não é possível apensar a uma multilinha fechada.
Fe_char
Fechado</translatorcomment>
        <translation>Fechado</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Bulge</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Bojo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start Width</source>
        <translation>Largura Inicial</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Width</source>
        <translation>Largura Final</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Width</source>
        <translation>Largura global</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orientation</source>
        <translation>Orientação</translation>
    </message>
    <message>
        <location line="+6"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Base Angle</source>
        <translation>Ângulo base</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Size 1</source>
        <translation>Tamanho 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Size 2</source>
        <translation>Tamanho 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Z</source>
        <translation>Z global</translation>
    </message>
    <message>
        <location filename="../src/entity/RFaceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 1</source>
        <translatorcomment>--google--
Ponto de Extensão 1|X
Ponto de Extensão 1|Y
Ponto 1|X</translatorcomment>
        <translation>Ponto 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 2</source>
        <translatorcomment>--google--
Ponto de Extensão 2|X
Ponto de Extensão 2|Y
Ponto 2|X</translatorcomment>
        <translation>Ponto 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 3</source>
        <translatorcomment>--google--
Ponto 3|X
Ponto 3|Y</translatorcomment>
        <translation>Ponto 3</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 4</source>
        <translatorcomment>--google--
Ponto 4|X
Ponto 4|Y</translatorcomment>
        <translation>Ponto 4</translation>
    </message>
    <message>
        <location filename="../src/entity/RSplineEntity.cpp" line="-12"/>
        <source>Closed Periodic</source>
        <translation>Fechado Periódico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translatorcomment>--exact match--
--file: qcadlib_pt.ts--
Graus Decimais
Grau:</translatorcomment>
        <translation>Grau</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Control Point</source>
        <translatorcomment>--google--
Indique o primeiro ponto de controle
Especifique o próximo ponto de controle ou [%1]
Especifique o próximo ponto de controle</translatorcomment>
        <translation>Ponto de Controle</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Fit Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ponto de Ajuste</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Knot Vector</source>
        <translation>Vetor de Nó</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Knot</source>
        <translation>Nó</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use Start Tangent</source>
        <translation>Use a tangente inicial</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Tangent</source>
        <translation>Tangente Inicial</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use End Tangent</source>
        <translation>Use a tangente final</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Tangent</source>
        <translation>Tangente Final</translation>
    </message>
    <message>
        <source>Simple</source>
        <translatorcomment>--google--
&lt;b&gt;P1&lt;/b&gt;: deslocamento simples
&lt;abbr title=\&quot;Really Simple Syndication\&quot;&gt;RSS&lt;/abbr&gt; feed para os comentários a este artigo.
&lt;abbr title=\&quot;Really Simple Syndication\&quot;&gt;RSS&lt;/abbr&gt; feed para os comentários a este artigo</translatorcomment>
        <translation type="vanished">Simples</translation>
    </message>
    <message>
        <source>Contents</source>
        <translatorcomment>--google--
Cole o conteúdo da área de transferência
Antever Conteúdo do Ficheiro
Tem a certeza que quer eliminar todo o conteúdo?</translatorcomment>
        <translation type="obsolete">Conteúdo</translation>
    </message>
    <message>
        <source>Text</source>
        <translation type="vanished">Texto</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation type="vanished">Texto Simples</translation>
    </message>
    <message>
        <source>Font Name</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Nome da Fonte</translation>
    </message>
    <message>
        <source>Text Height</source>
        <translation type="vanished">Altura do Texto</translation>
    </message>
    <message>
        <source>Text Angle</source>
        <translation type="vanished">Ângulo do Texto</translation>
    </message>
    <message>
        <source>X Scale</source>
        <translation type="vanished">Escala X</translation>
    </message>
    <message>
        <source>Bold</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Tornar negrito
Al_ternar
Negrito (Ctrl + B)
Negrito</translatorcomment>
        <translation type="vanished">Negrito</translation>
    </message>
    <message>
        <source>Italic</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
[10300-1032F] Itálico Antigo
Itálico
Itálico Clássico</translatorcomment>
        <translation type="vanished">Itálico</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translatorcomment>--google--
Espaçamento de linha:
Espaçamento de Linha &amp;Padrão
Espaçamento de Linha Padrão
Fator de Espaçamento de Linhas</translatorcomment>
        <translation type="vanished">Espaçamento da Linha</translation>
    </message>
    <message>
        <source>Alignment</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Alinhamento
Alinhamento|Vertical</translatorcomment>
        <translation type="vanished">Alinhamento</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Horizontal
Dimensão horizontal</translatorcomment>
        <translation type="vanished">Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translatorcomment>--exact match--
--file: pt.po--
&amp;Vertical
Dimensão vertical</translatorcomment>
        <translation type="vanished">Vertical</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeDefinitionEntity.cpp" line="+89"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+89"/>
        <source>Tag</source>
        <translation>Rótulo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prompt</source>
        <translation>Mensagem</translation>
    </message>
    <message>
        <location filename="../src/entity/RRayEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Base Point</source>
        <translation>Ponto de Base</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Second Point</source>
        <translation>Segundo Ponto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction Vector</source>
        <translation>Vetor de Direção</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+3"/>
        <source>Fixed Angle</source>
        <translation>Ângulo Fixo</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+1"/>
        <source>Invisible</source>
        <translation>Invisível</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+141"/>
        <source>Arc Symbol Type</source>
        <translation>Símbolo de arco</translation>
    </message>
</context>
</TS>
